@@ -1,6 +1,9 @@
 default_UI <- function(){
     
-    fluidPage(
+    fluidPage(theme = if(.MCE$shinyGUI$theme != '') 
+        if(requireNamespace("shinythemes", quietly = TRUE)){
+            shinythemes::shinytheme(.MCE$shinyGUI$theme)
+        } else NULL, 
         
         shiny::withMathJax(),
         
@@ -20,9 +23,8 @@ default_UI <- function(){
             if(.MCE$shinyGUI$author != '') h4("Authors:") else NULL,
             if(.MCE$shinyGUI$author != '') h5(.MCE$shinyGUI$author) else NULL,
             if(.MCE$shinyGUI$author != '') hr() else NULL,
-            h4(paste0("\n", .MCE$shinyGUI$instructions[1L])),
-            h5(.MCE$shinyGUI$instructions[2L]),            
-            actionButton("Next", .MCE$shinyGUI$instructions[3L])
+            helpText("\n", .MCE$shinyGUI$instructions[1L]),            
+            actionButton("Next", .MCE$shinyGUI$instructions[2L])
         ),
         
         mainPanel(
